@@ -30,10 +30,10 @@
 #include "tool.h"
 #include "stringdlg.h"
 #include <glib/gi18n-lib.h>
-#include <math.h>
 #include <unistd.h>
-#include <locale.h>
 #include <openbabel/obconversion.h>
+#include <cmath>
+#include <clocale>
 
 static void do_export_to_ghemical (gcpMolecule* pMol)
 {
@@ -352,7 +352,7 @@ bool gcpMolecule::Load (xmlNodePtr node)
 		SetId (buf);
 		xmlFree (buf);
 	}
-	child = GetNodeByName (node, "atom");
+	child = GetNodeByName (node, (char*) "atom");
 	while (child) {
 		pObject = new gcpAtom ();
 		if (pDoc)
@@ -364,10 +364,10 @@ bool gcpMolecule::Load (xmlNodePtr node)
 		if (pDoc)
 			pDoc->AddAtom ((gcpAtom*) pObject);
 		AddAtom ((gcpAtom*) pObject);
-		child = GetNextNodeByName (child->next, "atom");
+		child = GetNextNodeByName (child->next, (char*) "atom");
 	}
 	
-	child = GetNodeByName (node, "fragment");
+	child = GetNodeByName (node, (char*) "fragment");
 	while (child) {
 		pObject = new gcpFragment ();
 		AddChild (pObject);
@@ -378,10 +378,10 @@ bool gcpMolecule::Load (xmlNodePtr node)
 		if (pDoc)
 			pDoc->AddFragment ((gcpFragment*) pObject);
 		AddFragment ((gcpFragment*) pObject);
-		child = GetNextNodeByName (child->next, "fragment");
+		child = GetNextNodeByName (child->next, (char*) "fragment");
 	}
 
-	child = GetNodeByName (node, "bond");
+	child = GetNodeByName (node, (char*) "bond");
 	while (child) {
 		pObject = new gcpBond ();
 		AddBond ((gcpBond*) pObject);
@@ -392,7 +392,7 @@ bool gcpMolecule::Load (xmlNodePtr node)
 		}
 		if (pDoc)
 			pDoc->AddBond ((gcpBond*) pObject);
-		child = GetNextNodeByName (child->next, "bond");
+		child = GetNextNodeByName (child->next, (char*) "bond");
 		CheckCrossings ((gcpBond*) pObject);
 	}
 	if (!m_Atoms.empty ()) {
@@ -498,7 +498,7 @@ double gcpMolecule::GetYAlign ()
 	return (miny + maxy) / 2.0;
 }
 
-bool gcpMolecule::BuildContextualMenu (GtkUIManager *UIManager, Object *object)
+bool gcpMolecule::BuildContextualMenu (GtkUIManager *UIManager, Object *object, double x, double y)
 {
 	bool result = false;
 	GtkActionGroup *group = gtk_action_group_new ("molecule");
@@ -548,7 +548,7 @@ bool gcpMolecule::BuildContextualMenu (GtkUIManager *UIManager, Object *object)
 		gtk_ui_manager_insert_action_group (UIManager, group, 0);
 	else
 		g_object_unref (group);
-	return result | GetParent ()->BuildContextualMenu (UIManager, object);
+	return result | GetParent ()->BuildContextualMenu (UIManager, object, x, y);
 }
 
 void gcpMolecule::ExportToGhemical ()
