@@ -4,7 +4,7 @@
  * GChemPaint library
  * reaction.cc 
  *
- * Copyright (C) 2002-2006 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -29,11 +29,12 @@
 #include "document.h"
 #include "theme.h"
 #include "view.h"
-#include <math.h>
+#include <glib/gi18n-lib.h>
+#include <cmath>
 
 gcpReaction::gcpReaction (): Object (ReactionType)
 {
-	SetId ("rxn1");
+	SetId ((char*) "rxn1");
 }
 
 gcpReaction::~gcpReaction ()
@@ -59,17 +60,6 @@ gcpReaction::~gcpReaction ()
 	}
 }
 
-void gcpReaction::Add (GtkWidget* w)
-{
-	map<string, Object*>::iterator i;
-	Object* p = GetFirstChild (i);
-	while (p)
-	{
-		p->Add (w);
-		p = GetNextChild (i);
-	}
-}
-
 bool gcpReaction::Build (list<Object*>& Children) throw (invalid_argument)
 {
 	gcpDocument *pDoc = (gcpDocument*) GetDocument ();
@@ -157,13 +147,13 @@ bool gcpReaction::Build (list<Object*>& Children) throw (invalid_argument)
 			else
 				horiz = false;
 			if (horiz) {
-				l = x + pTheme->GetArrowPadding () * pTheme->GetZoomFactor ();
+				l = x + pTheme->GetArrowPadding ();
 				if (x1 < 0)
 					l = -l;
 				x0 += l;
 				y0 += l * y1 / x1;
 			} else {
-				l = y + pTheme->GetArrowPadding () * pTheme->GetZoomFactor ();
+				l = y + pTheme->GetArrowPadding ();
 				if (y1 < 0)
 					l = -l;
 				x0 += l * x1 / y1;
@@ -192,14 +182,14 @@ bool gcpReaction::Build (list<Object*>& Children) throw (invalid_argument)
 			}
 			if (horiz) {
 				x = srect.x1 - x0;
-				l = x + pTheme->GetArrowPadding () * pTheme->GetZoomFactor ();
+				l = x + pTheme->GetArrowPadding ();
 				if (x1 < 0)
 					l = -l;
 				x0 -= l;
 				y0 -= l * y1 / x1;
 			} else {
 				y = srect.y1 - y0;
-				l = y + pTheme->GetArrowPadding () * pTheme->GetZoomFactor ();
+				l = y + pTheme->GetArrowPadding ();
 				if (y1 < 0)
 					l = -l;
 				x0 -= l * x1 / y1;
@@ -262,13 +252,13 @@ bool gcpReaction::OnSignal (SignalId Signal, Object *Obj)
 					xpos = rect.x1 - x2;
 					ypos = rect.y1 - y2;
 					if (horiz) {
-						l = xpos + pTheme->GetArrowPadding () * pTheme->GetZoomFactor ();
+						l = xpos + pTheme->GetArrowPadding ();
 						if (x < 0)
 							l = -l;
 						x2 += l;
 						y2 += l * y / x;
 					} else {
-						l = ypos + pTheme->GetArrowPadding () * pTheme->GetZoomFactor ();
+						l = ypos + pTheme->GetArrowPadding ();
 						if (y < 0)
 							l = -l;
 						x2 += l * x / y;
@@ -286,14 +276,14 @@ bool gcpReaction::OnSignal (SignalId Signal, Object *Obj)
 					y2 = step->GetYAlign () * pTheme->GetZoomFactor ();
 					if (horiz) {
 						xpos = rect.x1 - x2;
-						l = xpos + pTheme->GetArrowPadding () * pTheme->GetZoomFactor ();
+						l = xpos + pTheme->GetArrowPadding ();
 						if (x < 0)
 							l = -l;
 						x2 -= l;
 						y2 -= l * y / x;
 					} else {
 						ypos = rect.y1 - y2;
-						l = ypos + pTheme->GetArrowPadding () * pTheme->GetZoomFactor ();
+						l = ypos + pTheme->GetArrowPadding ();
 						if (y < 0)
 							l = -l;
 						x2 -= l * x / y;
@@ -373,7 +363,7 @@ static void do_destroy_reaction (void *data)
 	pDoc->FinishOperation ();
 }
 
-bool gcpReaction::BuildContextualMenu (GtkUIManager *UIManager, Object *object)
+bool gcpReaction::BuildContextualMenu (GtkUIManager *UIManager, Object *object, double x, double y)
 {
 	GtkActionGroup *group = gtk_action_group_new ("reaction");
 	GtkAction *action = gtk_action_new ("destroy", _("Destroy the reaction"), NULL, NULL);
@@ -383,7 +373,7 @@ bool gcpReaction::BuildContextualMenu (GtkUIManager *UIManager, Object *object)
 	gtk_ui_manager_add_ui_from_string (UIManager, buf, -1, NULL);
 	GtkWidget *w = gtk_ui_manager_get_widget (UIManager, "/popup/destroy");
 	g_signal_connect_swapped (w, "activate", G_CALLBACK (do_destroy_reaction), this);
-	GetParent ()->BuildContextualMenu (UIManager, object);
+	GetParent ()->BuildContextualMenu (UIManager, object, x, y);
 	return true;
 }
 
