@@ -198,11 +198,13 @@ gcpView::gcpView (gcpDocument *pDoc, bool Embedded)
 	m_UIManager = gtk_ui_manager_new ();
 	m_Dragging = false;
 	m_pWidget = NULL;
+	m_PangoContext = NULL;
 }
 
 gcpView::~gcpView ()
 {
-	g_object_unref (G_OBJECT (m_PangoContext));
+	if (m_PangoContext)
+		g_object_unref (G_OBJECT (m_PangoContext));
 	if (m_sFontName)
 		g_free (m_sFontName);
 	if (m_sSmallFontName)
