@@ -148,7 +148,7 @@ static void on_delete_template (GtkWidget *w, gcpTemplateTool *tool)
 
 GtkWidget *gcpTemplateTool::GetPropertyPage ()
 {
-	GladeXML *xml = glade_xml_new (DATADIR"/gchempaint-unstable/ui/templates.glade", "templates", GETTEXT_PACKAGE);
+	GladeXML *xml = glade_xml_new (GLADEDIR"/templates.glade", "templates", GETTEXT_PACKAGE);
 	gcpTemplateTree *tree = (gcpTemplateTree*) m_pApp->GetTool ("TemplateTree");
 	if (!tree)
 		return NULL;
@@ -275,7 +275,7 @@ void gcpTemplateTool::OnDeleteTemplate ()
 }
 
 gcpNewTemplateToolDlg::gcpNewTemplateToolDlg(gcpApplication* App):
-	Dialog(App, DATADIR"/gchempaint-unstable/ui/new-template.glade", "new_template", App)
+	Dialog(App, GLADEDIR"/new-template.glade", "new_template", App)
 {
 	m_node = NULL;
 	if (!xml) {
